package cc.fascinated.bat.features.autorole.command;

import cc.fascinated.bat.command.BatSubCommand;
import cc.fascinated.bat.common.EmbedUtils;
import cc.fascinated.bat.features.autorole.profile.AutoRoleProfile;
import cc.fascinated.bat.model.BatGuild;
import cc.fascinated.bat.model.BatUser;
import cc.fascinated.bat.service.GuildService;
import lombok.NonNull;
import net.dv8tion.jda.api.EmbedBuilder;
import net.dv8tion.jda.api.entities.Member;
import net.dv8tion.jda.api.entities.Role;
import net.dv8tion.jda.api.entities.channel.concrete.TextChannel;
import net.dv8tion.jda.api.interactions.commands.OptionMapping;
import net.dv8tion.jda.api.interactions.commands.SlashCommandInteraction;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @author Fascinated (fascinated7)
 */
@Component("autoroles:add.sub")
public class AddSubCommand extends BatSubCommand {
    private final GuildService guildService;

    @Autowired
    public AddSubCommand(GuildService guildService) {
        this.guildService = guildService;
    }

    @Override
    public void execute(@NonNull BatGuild guild, @NonNull BatUser user, @NonNull TextChannel channel, @NonNull Member member, @NonNull SlashCommandInteraction interaction) {
        AutoRoleProfile profile = guild.getProfile(AutoRoleProfile.class);
        if (profile.getRoleSlotsInUse() >= profile.getMaxRoles()) {
            interaction.replyEmbeds(EmbedUtils.buildErrorEmbed()
                    .setDescription("You can only have a maximum of %d roles set for the auto role feature"
                    .formatted(profile.getMaxRoles()))
                    .build()).queue();
            return;
        }

        OptionMapping option = interaction.getOption("role");
        if (option == null) {
            interaction.replyEmbeds(EmbedUtils.buildErrorEmbed()
                    .setDescription("Please provide a role to add")
                    .build()).queue();
            return;
        }

        Role role = option.getAsRole();
        if (profile.hasRole(role.getId())) {
            interaction.replyEmbeds(EmbedUtils.buildErrorEmbed()
                    .setDescription("The role %s is already in the auto roles list".formatted(role.getAsMention()))
                    .build()).queue();
            return;
        }

        profile.addRole(role.getId());
        guildService.saveGuild(guild);
        interaction.replyEmbeds(EmbedUtils.buildSuccessEmbed()
                .setDescription("Successfully added the role %s to the auto roles list".formatted(role.getAsMention()))
                .build()).queue();
    }
}
