package cc.fascinated.bat.features.autorole.command;

import cc.fascinated.bat.command.BatCommand;
import lombok.NonNull;
import net.dv8tion.jda.api.Permission;
import net.dv8tion.jda.api.interactions.commands.DefaultMemberPermissions;
import net.dv8tion.jda.api.interactions.commands.OptionType;
import net.dv8tion.jda.api.interactions.commands.build.OptionData;
import net.dv8tion.jda.api.interactions.commands.build.SubcommandData;
import net.dv8tion.jda.internal.interactions.CommandDataImpl;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

/**
 * @author Fascinated (fascinated7)
 */
@Component("autoroles.command")
public class AutoRoleCommand extends BatCommand {
    public AutoRoleCommand(@NonNull ApplicationContext context) {
        super("autorole");
        super.setDescription("Set up the automatic role system for members on join");

        super.addSubCommand("list", context.getBean(ListSubCommand.class));
        super.addSubCommand("add", context.getBean(AddSubCommand.class));
        super.addSubCommand("remove", context.getBean(RemoveSubCommand.class));
        super.addSubCommand("clear", context.getBean(ClearSubCommand.class));

        super.setCommandData(new CommandDataImpl(this.getName(), this.getDescription())
                .setGuildOnly(true)
                .addSubcommands(new SubcommandData("list", "Show the current automatic roles"))
                    .setDefaultPermissions(DefaultMemberPermissions.enabledFor(Permission.MANAGE_SERVER))
                .addSubcommands(new SubcommandData("add", "Add an automatic role")
                        .addOptions(new OptionData(OptionType.ROLE, "role", "The role to add", true))
                ).setDefaultPermissions(DefaultMemberPermissions.enabledFor(Permission.MANAGE_SERVER))
                .addSubcommands(new SubcommandData("remove", "Remove an automatic role")
                        .addOptions(new OptionData(OptionType.ROLE, "role", "The role to remove", true))
                ).setDefaultPermissions(DefaultMemberPermissions.enabledFor(Permission.MANAGE_SERVER))
                .addSubcommands(new SubcommandData("clear", "Clears all automatic roles"))
                    .setDefaultPermissions(DefaultMemberPermissions.enabledFor(Permission.MANAGE_SERVER))
        );
    }
}
